# rdltr

[![Python Version](https://img.shields.io/badge/python-3.6+-brightgreen.svg)](https://python.org)
[![Flask Version](https://img.shields.io/badge/flask-1.0-brightgreen.svg)](http://flask.pocoo.org/)
[![Vue Version](https://img.shields.io/badge/vue-2.6.8-brightgreen.svg)](https://vuejs.org/)  
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/70a84eefaea5413abf464a053abf9d19)](https://www.codacy.com/app/SamR1/rdltr)
[![Coverage Status](https://coveralls.io/repos/github/SamR1/rdltr/badge.svg?branch=master)](https://coveralls.io/github/SamR1/rdltr?branch=master)<sup><sup>1</sup></sup>
[![Build Status](https://travis-ci.org/SamR1/rdltr.svg?branch=master)](https://travis-ci.org/SamR1/rdltr)

----

**rdltr** is a _read-it later_ web application: save articles for later reading.  
Categories and tags can be used to classify articles. 

Initially a small project to learn Vue (with Flask)<sup>2</sup>, **rdltr** uses **readability-lxml** to parse HTML content (see [wiki](https://github.com/SamR1/rdltr/wiki) for installation instructions).

![application snapshot](https://raw.githubusercontent.com/SamR1/rdltr/master/docs/snapshot.png)  

---

Notes:  
_1. test coverage: only for Python_  
_2. application structure inspired by this tutorial: [Full-stack single page application with Vue.js and Flask](https://codeburst.io/full-stack-single-page-application-with-vue-js-and-flask-b1e036315532)_  
